@@ -165,17 +165,16 @@ class ApiCammesa():
         Devuelve un dataframe de pandas con todos los archivos encontrados en dicho rango.
         NO FILTRA ni elimina duplicados en caso de existir varias versiones del mismo reporte (final/inicial)'''
 
-        if filtro == False:
-                print('Sin parámetro ni atributo detectado de "filtro". Colocando filtro = ultimos.')
-                self.filtro = 'ultimos'
-        else:
-            self.filtro = filtro
+
+        self.filtro = 'ultimos' if filtro is None else filtro
 
         print("Procediendo a consultar API de CAMMESA.")
-        r_parsed = self.__docs_by_nemo_rango(fecha_i, fecha_f,nemo_rpt=nemo_rpt)
 
         df_inicial = (pd
-            .DataFrame(list(r_parsed))
+            .DataFrame(list(
+                    self.__docs_by_nemo_rango(fecha_i, fecha_f, nemo_rpt = nemo_rpt)
+                )
+            )
             .assign(
                 adjuntos = lambda adf: adf.adjuntos.apply(list),
                 fecha = lambda adf: pd.to_datetime(adf.fecha, format='%d/%m/%Y'),
@@ -203,7 +202,7 @@ class ApiCammesa():
             if self.filtro in self.filtro_custom_dict:
                 #Esto implica que el filtro solicitado es una función custom 
                 self._consulta_custom = self._filtro_func_custom(df_total)
-            
+        
         if exportar_consulta:
             print("Exportando consulta realizada a la API de CAMMESA.")
             
