@@ -18,7 +18,6 @@ class TablasVC(SQLConnector):
         cargar_incidencias = False,
         cargar_datos_basicos = 'offline',
         parques = [],
-        clientes = [],
         solo_CROM = False,
         mensajes=True,
         ):
@@ -33,7 +32,7 @@ class TablasVC(SQLConnector):
             self.__parques = [parques,]
         else:
             self.__parques = parques
-        self.__clientes = clientes
+
         self.solo_CROM = solo_CROM
         
         self.incidencias_todas_auditoria = None
@@ -93,25 +92,10 @@ class TablasVC(SQLConnector):
     def parques(self,val):
         self.__check_cliente_parque(val,tipo='parques')
         if val != []:
-            self.clientes = []
-            
             val = [v for v in val if v != '']
-            
-    
         self.__parques = val
     
-    @property
-    def clientes(self):
-        return self.__clientes
-    
-    @clientes.setter
-    def clientes(self,val):
-        self.__check_cliente_parque(val,tipo='clientes')
-        if val != []:
-            self.parques = []
-        
-        self.__clientes = val
-    
+   
     @property
     def idsApiCammesa(self):
         if self._idsApiCammesa == {}:
@@ -184,9 +168,7 @@ class TablasVC(SQLConnector):
         # Chequea si los parámetros de carga "cargar_incidencias" o "cargar_datos_básicos" 
         # tienen parámetros válidos
         
-        valores_posibles_bool = [False, True]
         valores_posibles_str = ['online','offline'] 
-        valores_posibles = valores_posibles_str + valores_posibles_bool
         
         if not isinstance(val,(bool,str)):
             raise TypeError(f'El parámetro {param} = {val} debe ser del tipo bool/str y se recibió {type(val)}')
